from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from .........Internal.RepeatedCapability import RepeatedCapability
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AnPattern:
	"""AnPattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: AntennaPattern, default value after init: AntennaPattern.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("anPattern", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_antennaPattern_get', 'repcap_antennaPattern_set', repcap.AntennaPattern.Nr0)

	def repcap_antennaPattern_set(self, enum_value: repcap.AntennaPattern) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AntennaPattern.Default
		Default value after init: AntennaPattern.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_antennaPattern_get(self) -> repcap.AntennaPattern:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, an_pattern: str, subframeNull=repcap.SubframeNull.Default, antennaPattern=repcap.AntennaPattern.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PHICh:ANPattern<GR0> \n
		Snippet: driver.source.bb.eutra.downlink.subf.encc.phich.anPattern.set(an_pattern = '1', subframeNull = repcap.SubframeNull.Default, antennaPattern = repcap.AntennaPattern.Default) \n
		No command help available \n
			:param an_pattern: No help available
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param antennaPattern: optional repeated capability selector. Default value: Nr0 (settable in the interface 'AnPattern')"""
		param = Conversions.value_to_quoted_str(an_pattern)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		antennaPattern_cmd_val = self._base.get_repcap_cmd_value(antennaPattern, repcap.AntennaPattern)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PHICh:ANPattern{antennaPattern_cmd_val} {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default, antennaPattern=repcap.AntennaPattern.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PHICh:ANPattern<GR0> \n
		Snippet: value: str = driver.source.bb.eutra.downlink.subf.encc.phich.anPattern.get(subframeNull = repcap.SubframeNull.Default, antennaPattern = repcap.AntennaPattern.Default) \n
		No command help available \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param antennaPattern: optional repeated capability selector. Default value: Nr0 (settable in the interface 'AnPattern')
			:return: an_pattern: No help available"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		antennaPattern_cmd_val = self._base.get_repcap_cmd_value(antennaPattern, repcap.AntennaPattern)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PHICh:ANPattern{antennaPattern_cmd_val}?')
		return trim_str_response(response)

	def clone(self) -> 'AnPattern':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AnPattern(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rate:
	"""Rate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rate", core, parent)

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:DATA:RATE \n
		Snippet: value: float = driver.source.bb.wlnn.fblock.user.data.rate.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		The command queries the PPDU data rate. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: rate: float"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:DATA:RATE?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Csettings:
	"""Csettings commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("csettings", core, parent)

	def get_ra_rnti(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CSETtings:RARNti \n
		Snippet: value: int = driver.source.bb.eutra.downlink.csettings.get_ra_rnti() \n
		Sets the random-access response identity RA-RNTI. The value selected here determines the value of the parameter
		'UE_ID/n_RNTI' in case a RA_RNTI 'User' is selected. \n
			:return: ra_rnti: integer Range: 1 to 60
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:CSETtings:RARNti?')
		return Conversions.str_to_int(response)

	def set_ra_rnti(self, ra_rnti: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CSETtings:RARNti \n
		Snippet: driver.source.bb.eutra.downlink.csettings.set_ra_rnti(ra_rnti = 1) \n
		Sets the random-access response identity RA-RNTI. The value selected here determines the value of the parameter
		'UE_ID/n_RNTI' in case a RA_RNTI 'User' is selected. \n
			:param ra_rnti: integer Range: 1 to 60
		"""
		param = Conversions.decimal_value_to_str(ra_rnti)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:CSETtings:RARNti {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Laa:
	"""Laa commands group definition. 9 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("laa", core, parent)

	@property
	def cell(self):
		"""cell commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cell'):
			from .Cell import Cell
			self._cell = Cell(self._core, self._base)
		return self._cell

	# noinspection PyTypeChecker
	def get_ce_index(self) -> enums.EutraCcIndexS:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:LAA:CEINdex \n
		Snippet: value: enums.EutraCcIndexS = driver.source.bb.eutra.downlink.laa.get_ce_index() \n
		Selects the LAA SCell for that the LAA is configured. \n
			:return: cell_index: SC1| SC2| SC3| SC4| NONE
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:LAA:CEINdex?')
		return Conversions.str_to_scalar_enum(response, enums.EutraCcIndexS)

	def set_ce_index(self, cell_index: enums.EutraCcIndexS) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:LAA:CEINdex \n
		Snippet: driver.source.bb.eutra.downlink.laa.set_ce_index(cell_index = enums.EutraCcIndexS.NONE) \n
		Selects the LAA SCell for that the LAA is configured. \n
			:param cell_index: SC1| SC2| SC3| SC4| NONE
		"""
		param = Conversions.enum_scalar_to_str(cell_index, enums.EutraCcIndexS)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:LAA:CEINdex {param}')

	def clone(self) -> 'Laa':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Laa(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setting:
	"""Setting commands group definition. 16 total commands, 2 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("setting", core, parent)

	@property
	def tmodel(self):
		"""tmodel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tmodel'):
			from .Tmodel import Tmodel
			self._tmodel = Tmodel(self._core, self._base)
		return self._tmodel

	@property
	def tsetup(self):
		"""tsetup commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tsetup'):
			from .Tsetup import Tsetup
			self._tsetup = Tsetup(self._core, self._base)
		return self._tsetup

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.w3Gpp.setting.get_catalog() \n
		This command reads out the files with 3GPP FDD settings in the default directory. The default directory is set using
		command method RsSmw.MassMemory.currentDirectory. Only files with the file extension *.3g are listed. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def delete(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:SETTing:DELete \n
		Snippet: driver.source.bb.w3Gpp.setting.delete(filename = '1') \n
		This command deletes the selected file with 3GPP FDD settings. The directory is set using command method RsSmw.MassMemory.
		currentDirectory. A path can also be specified, in which case the files in the specified directory are read. The file
		extension can be omitted. Only files with the file extension *.3g are deleted. \n
			:param filename: file_name
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:SETTing:DELete {param}')

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:SETTing:LOAD \n
		Snippet: driver.source.bb.w3Gpp.setting.load(filename = '1') \n
		This command loads the selected file with 3GPP FDD settings. The directory is set using command method RsSmw.MassMemory.
		currentDirectory. A path can also be specified, in which case the files in the specified directory are read. The file
		extension can be omitted. Only files with the file extension *.3g are loaded. \n
			:param filename: file_name
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:SETTing:LOAD {param}')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:SETTing:STORe \n
		Snippet: driver.source.bb.w3Gpp.setting.set_store(filename = '1') \n
		This command stores the current 3GPP FDD settings into the selected file. The directory is set using command method RsSmw.
		MassMemory.currentDirectory. A path can also be specified, in which case the files in the specified directory are read.
		Only enter the file name. 3GPP FDD settings are stored as files with the specific file extensions *.3g. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:SETTing:STORe {param}')

	def clone(self) -> 'Setting':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Setting(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dg:
	"""Dg commands group definition. 16 total commands, 12 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dg", core, parent)

	@property
	def ccgp(self):
		"""ccgp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccgp'):
			from .Ccgp import Ccgp
			self._ccgp = Ccgp(self._core, self._base)
		return self._ccgp

	@property
	def file(self):
		"""file commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_file'):
			from .File import File
			self._file = File(self._core, self._base)
		return self._file

	@property
	def gpolynomial(self):
		"""gpolynomial commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_gpolynomial'):
			from .Gpolynomial import Gpolynomial
			self._gpolynomial = Gpolynomial(self._core, self._base)
		return self._gpolynomial

	@property
	def m11state(self):
		"""m11state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_m11state'):
			from .M11state import M11state
			self._m11state = M11state(self._core, self._base)
		return self._m11state

	@property
	def m1state(self):
		"""m1state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_m1state'):
			from .M1state import M1state
			self._m1state = M1state(self._core, self._base)
		return self._m1state

	@property
	def predefined(self):
		"""predefined commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_predefined'):
			from .Predefined import Predefined
			self._predefined = Predefined(self._core, self._base)
		return self._predefined

	@property
	def rbOrder(self):
		"""rbOrder commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_rbOrder'):
			from .RbOrder import RbOrder
			self._rbOrder = RbOrder(self._core, self._base)
		return self._rbOrder

	@property
	def sfile(self):
		"""sfile commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfile'):
			from .Sfile import Sfile
			self._sfile = Sfile(self._core, self._base)
		return self._sfile

	@property
	def spredefined(self):
		"""spredefined commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_spredefined'):
			from .Spredefined import Spredefined
			self._spredefined = Spredefined(self._core, self._base)
		return self._spredefined

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def suser(self):
		"""suser commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_suser'):
			from .Suser import Suser
			self._suser = Suser(self._core, self._base)
		return self._suser

	@property
	def user(self):
		"""user commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_user'):
			from .User import User
			self._user = User(self._core, self._base)
		return self._user

	def clone(self) -> 'Dg':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dg(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mbsfn:
	"""Mbsfn commands group definition. 37 total commands, 4 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mbsfn", core, parent)

	@property
	def ai(self):
		"""ai commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_ai'):
			from .Ai import Ai
			self._ai = Ai(self._core, self._base)
		return self._ai

	@property
	def mtch(self):
		"""mtch commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_mtch'):
			from .Mtch import Mtch
			self._mtch = Mtch(self._core, self._base)
		return self._mtch

	@property
	def pmch(self):
		"""pmch commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_pmch'):
			from .Pmch import Pmch
			self._pmch = Pmch(self._core, self._base)
		return self._pmch

	@property
	def sc(self):
		"""sc commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_sc'):
			from .Sc import Sc
			self._sc = Sc(self._core, self._base)
		return self._sc

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.EutraMbsfnType:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:MODE \n
		Snippet: value: enums.EutraMbsfnType = driver.source.bb.eutra.downlink.mbsfn.get_mode() \n
		Enables the MBSFN transmission and selects a mixed MBSFN Mode. \n
			:return: mbsfn_mode: OFF| MIXed
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraMbsfnType)

	def set_mode(self, mbsfn_mode: enums.EutraMbsfnType) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:MODE \n
		Snippet: driver.source.bb.eutra.downlink.mbsfn.set_mode(mbsfn_mode = enums.EutraMbsfnType.MIXed) \n
		Enables the MBSFN transmission and selects a mixed MBSFN Mode. \n
			:param mbsfn_mode: OFF| MIXed
		"""
		param = Conversions.enum_scalar_to_str(mbsfn_mode, enums.EutraMbsfnType)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:MODE {param}')

	def get_rhoa(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:RHOA \n
		Snippet: value: float = driver.source.bb.eutra.downlink.mbsfn.get_rhoa() \n
		Defines the power of the MBSFN channels relative to the common Reference Signals. \n
			:return: rhoa: float Range: -80 to 10
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:RHOA?')
		return Conversions.str_to_float(response)

	def set_rhoa(self, rhoa: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:RHOA \n
		Snippet: driver.source.bb.eutra.downlink.mbsfn.set_rhoa(rhoa = 1.0) \n
		Defines the power of the MBSFN channels relative to the common Reference Signals. \n
			:param rhoa: float Range: -80 to 10
		"""
		param = Conversions.decimal_value_to_str(rhoa)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:RHOA {param}')

	# noinspection PyTypeChecker
	def get_uec(self) -> enums.UeCat:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:UEC \n
		Snippet: value: enums.UeCat = driver.source.bb.eutra.downlink.mbsfn.get_uec() \n
		Defines the UE category as defined in . \n
			:return: ue_category: C1| C2| C3| C4| C5
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:UEC?')
		return Conversions.str_to_scalar_enum(response, enums.UeCat)

	def set_uec(self, ue_category: enums.UeCat) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:MBSFn:UEC \n
		Snippet: driver.source.bb.eutra.downlink.mbsfn.set_uec(ue_category = enums.UeCat.C1) \n
		Defines the UE category as defined in . \n
			:param ue_category: C1| C2| C3| C4| C5
		"""
		param = Conversions.enum_scalar_to_str(ue_category, enums.UeCat)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:MBSFn:UEC {param}')

	def clone(self) -> 'Mbsfn':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Mbsfn(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rwindow:
	"""Rwindow commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rwindow", core, parent)

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def set(self, rep_window: int, vehicle=repcap.Vehicle.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:RWINdow \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.rwindow.set(rep_window = 1, vehicle = repcap.Vehicle.Default) \n
		Sets the repeating period (in km or s) of repeating objects. \n
			:param rep_window: integer Range: 0 to 1000
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')"""
		param = Conversions.decimal_value_to_str(rep_window)
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:RWINdow {param}')

	def get(self, vehicle=repcap.Vehicle.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:RWINdow \n
		Snippet: value: int = driver.source.bb.gnss.receiver.v.environment.full.rwindow.get(vehicle = repcap.Vehicle.Default) \n
		Sets the repeating period (in km or s) of repeating objects. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: rep_window: integer Range: 0 to 1000"""
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:RWINdow?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'Rwindow':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rwindow(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Profile:
	"""Profile commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("profile", core, parent)

	def set(self, profile: enums.Doppler, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:NAVic:SDYNamics:PROFile \n
		Snippet: driver.source.bb.gnss.svid.navic.sdynamics.profile.set(profile = enums.Doppler.CONStant, satelliteSvid = repcap.SatelliteSvid.Default) \n
		Selects the dynamics profile type. \n
			:param profile: CONStant| HIGH CONStant Constant velocity as set with the command [:SOURcehw]:BB:GNSS:SVIDch:GPS:SDYNamics:VELocity. HIGH Profiles with higher-order dynamics as set with the command [:SOURcehw]:BB:GNSS:SVIDch:GPS:SDYNamics:CONFig.
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')"""
		param = Conversions.enum_scalar_to_str(profile, enums.Doppler)
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:NAVic:SDYNamics:PROFile {param}')

	# noinspection PyTypeChecker
	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> enums.Doppler:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:NAVic:SDYNamics:PROFile \n
		Snippet: value: enums.Doppler = driver.source.bb.gnss.svid.navic.sdynamics.profile.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		Selects the dynamics profile type. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: profile: CONStant| HIGH CONStant Constant velocity as set with the command [:SOURcehw]:BB:GNSS:SVIDch:GPS:SDYNamics:VELocity. HIGH Profiles with higher-order dynamics as set with the command [:SOURcehw]:BB:GNSS:SVIDch:GPS:SDYNamics:CONFig."""
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:NAVic:SDYNamics:PROFile?')
		return Conversions.str_to_scalar_enum(response, enums.Doppler)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SeqElem:
	"""SeqElem commands group definition. 12 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("seqElem", core, parent)

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import Conflict
			self._conflict = Conflict(self._core, self._base)
		return self._conflict

	@property
	def harq(self):
		"""harq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_harq'):
			from .Harq import Harq
			self._harq = Harq(self._core, self._base)
		return self._harq

	@property
	def pdre(self):
		"""pdre commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pdre'):
			from .Pdre import Pdre
			self._pdre = Pdre(self._core, self._base)
		return self._pdre

	@property
	def subframe(self):
		"""subframe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subframe'):
			from .Subframe import Subframe
			self._subframe = Subframe(self._core, self._base)
		return self._subframe

	@property
	def tb1(self):
		"""tb1 commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_tb1'):
			from .Tb1 import Tb1
			self._tb1 = Tb1(self._core, self._base)
		return self._tb1

	@property
	def tb2(self):
		"""tb2 commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_tb2'):
			from .Tb2 import Tb2
			self._tb2 = Tb2(self._core, self._base)
		return self._tb2

	def clone(self) -> 'SeqElem':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SeqElem(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Predefined:
	"""Predefined commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("predefined", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:NOISe:PHASenoise:SHAPe:PREDefined:CATalog \n
		Snippet: value: List[str] = driver.source.noise.phasenoise.shape.predefined.get_catalog() \n
		Queries the files with predefined settings. Listed are files with the file extension *.fcf. Refer to 'Accessing Files in
		the Default or in a Specified Directory' for general information on file handling in the default and in a specific
		directory. \n
			:return: nois_phas_ssb_shap_pre_def_cat_nam: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:NOISe:PHASenoise:SHAPe:PREDefined:CATalog?')
		return Conversions.str_to_str_list(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.StructBase import StructBase
from ....Internal.ArgStruct import ArgStruct
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Configuration:
	"""Configuration commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("configuration", core, parent)

	def set(self, dev_board: str, point: str, data: str) -> None:
		"""SCPI: DIAGnostic<HW>:POINt:CONFiguration \n
		Snippet: driver.diagnostic.point.configuration.set(dev_board = '1', point = '1', data = '1') \n
		No command help available \n
			:param dev_board: No help available
			:param point: No help available
			:param data: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('dev_board', dev_board, DataType.String), ArgSingle('point', point, DataType.String), ArgSingle('data', data, DataType.String))
		self._core.io.write(f'DIAGnostic<HwInstance>:POINt:CONFiguration {param}'.rstrip())

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Dev_Board: str: No parameter help available
			- Point: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_str('Dev_Board'),
			ArgStruct.scalar_str('Point')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Dev_Board: str = None
			self.Point: str = None

	def get(self) -> GetStruct:
		"""SCPI: DIAGnostic<HW>:POINt:CONFiguration \n
		Snippet: value: GetStruct = driver.diagnostic.point.configuration.get() \n
		No command help available \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'DIAGnostic<HwInstance>:POINt:CONFiguration?', self.__class__.GetStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pattern:
	"""Pattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pattern", core, parent)

	def set(self, pattern: enums.TxDiv, baseStation=repcap.BaseStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:ENHanced:PCPich:PATTern \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.pcpich.pattern.set(pattern = enums.TxDiv.ANT1, baseStation = repcap.BaseStation.Default) \n
		Sets the P-CPICh pattern (channel 0) . \n
			:param pattern: ANT1| ANT2
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')"""
		param = Conversions.enum_scalar_to_str(pattern, enums.TxDiv)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:ENHanced:PCPich:PATTern {param}')

	# noinspection PyTypeChecker
	def get(self, baseStation=repcap.BaseStation.Default) -> enums.TxDiv:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:ENHanced:PCPich:PATTern \n
		Snippet: value: enums.TxDiv = driver.source.bb.w3Gpp.bstation.enhanced.pcpich.pattern.get(baseStation = repcap.BaseStation.Default) \n
		Sets the P-CPICh pattern (channel 0) . \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:return: pattern: ANT1| ANT2"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:ENHanced:PCPich:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.TxDiv)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Setting:
	"""Setting commands group definition. 6 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("setting", core, parent)

	@property
	def tmod(self):
		"""tmod commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_tmod'):
			from .Tmod import Tmod
			self._tmod = Tmod(self._core, self._base)
		return self._tmod

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:SETTing:CATalog \n
		Snippet: value: List[str] = driver.source.bb.eutra.setting.get_catalog() \n
		Queries the files with settings in the default directory. Listed are files with the file extension *.lte.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: catalog: filename1,filename2,... Returns a string of filenames separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:SETTing:CATalog?')
		return Conversions.str_to_str_list(response)

	def set_del_py(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:SETTing:DEL \n
		Snippet: driver.source.bb.eutra.setting.set_del_py(filename = '1') \n
		Deletes the selected file from the default or the specified directory. Deleted are files with extension *.lte. Refer to
		'Accessing Files in the Default or Specified Directory' for general information on file handling in the default and in a
		specific directory. \n
			:param filename: string Filename or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:SETTing:DEL {param}')

	def get_load(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:SETTing:LOAD \n
		Snippet: value: str = driver.source.bb.eutra.setting.get_load() \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.lte.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: filename: string Filename or complete file path; file extension can be omitted
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:SETTing:LOAD?')
		return trim_str_response(response)

	def set_load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:SETTing:LOAD \n
		Snippet: driver.source.bb.eutra.setting.set_load(filename = '1') \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.lte.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string Filename or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:SETTing:LOAD {param}')

	def get_store(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:SETTing:STORe \n
		Snippet: value: str = driver.source.bb.eutra.setting.get_store() \n
		Stores the current settings into the selected file; the file extension (*.lte) is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: filename: string Filename or complete file path
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EUTRa:SETTing:STORe?')
		return trim_str_response(response)

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:SETTing:STORe \n
		Snippet: driver.source.bb.eutra.setting.set_store(filename = '1') \n
		Stores the current settings into the selected file; the file extension (*.lte) is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string Filename or complete file path
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:SETTing:STORe {param}')

	def clone(self) -> 'Setting':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Setting(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Regenerator:
	"""Regenerator commands group definition. 78 total commands, 7 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("regenerator", core, parent)

	@property
	def diagram(self):
		"""diagram commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_diagram'):
			from .Diagram import Diagram
			self._diagram = Diagram(self._core, self._base)
		return self._diagram

	@property
	def object(self):
		"""object commands group. 15 Sub-classes, 2 commands."""
		if not hasattr(self, '_object'):
			from .Object import Object
			self._object = Object(self._core, self._base)
		return self._object

	@property
	def radar(self):
		"""radar commands group. 4 Sub-classes, 1 commands."""
		if not hasattr(self, '_radar'):
			from .Radar import Radar
			self._radar = Radar(self._core, self._base)
		return self._radar

	@property
	def restart(self):
		"""restart commands group. 3 Sub-classes, 4 commands."""
		if not hasattr(self, '_restart'):
			from .Restart import Restart
			self._restart = Restart(self._core, self._base)
		return self._restart

	@property
	def simulation(self):
		"""simulation commands group. 5 Sub-classes, 6 commands."""
		if not hasattr(self, '_simulation'):
			from .Simulation import Simulation
			self._simulation = Simulation(self._core, self._base)
		return self._simulation

	@property
	def test(self):
		"""test commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_test'):
			from .Test import Test
			self._test = Test(self._core, self._base)
		return self._test

	@property
	def unit(self):
		"""unit commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_unit'):
			from .Unit import Unit
			self._unit = Unit(self._core, self._base)
		return self._unit

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:REGenerator:CATalog \n
		Snippet: value: List[str] = driver.source.regenerator.get_catalog() \n
		Queries the files with settings in the default directory. Listed are files with the file extension *.reg.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:return: filenames: filename1,filename2,... Returns a string of file names separated by commas.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:CATalog?')
		return Conversions.str_to_str_list(response)

	def load(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:LOAD \n
		Snippet: driver.source.regenerator.load(filename = '1') \n
		Loads the selected file from the default or the specified directory. Loaded are files with extension *.reg.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string file name or complete file path; file extension can be omitted
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:LOAD {param}')

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:PRESet \n
		Snippet: driver.source.regenerator.preset() \n
		Calls the default settings. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:PRESet')

	def preset_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:PRESet \n
		Snippet: driver.source.regenerator.preset_with_opc() \n
		Calls the default settings. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:REGenerator:PRESet')

	def set_store(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:STORe \n
		Snippet: driver.source.regenerator.set_store(filename = '1') \n
		Stores the current settings into the selected file; the file extension (*.reg) is assigned automatically.
		Refer to 'Accessing Files in the Default or Specified Directory' for general information on file handling in the default
		and in a specific directory. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:STORe {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:REGenerator:[STATe] \n
		Snippet: value: bool = driver.source.regenerator.get_state() \n
		Enables/disables the Radar Echo Generation. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:REGenerator:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:REGenerator:[STATe] \n
		Snippet: driver.source.regenerator.set_state(state = False) \n
		Enables/disables the Radar Echo Generation. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:REGenerator:STATe {param}')

	def clone(self) -> 'Regenerator':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Regenerator(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Execute:
	"""Execute commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("execute", core, parent)

	def set(self) -> None:
		"""SCPI: [SOURce<HW>]:LIST:DEXChange:EXECute \n
		Snippet: driver.source.listPy.dexchange.execute.set() \n
		Executes the import or export of the selected list file, according to the previously set transfer direction with command
		method RsSmw.Source.ListPy.Dexchange.mode \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:LIST:DEXChange:EXECute')

	def set_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:LIST:DEXChange:EXECute \n
		Snippet: driver.source.listPy.dexchange.execute.set_with_opc() \n
		Executes the import or export of the selected list file, according to the previously set transfer direction with command
		method RsSmw.Source.ListPy.Dexchange.mode \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:LIST:DEXChange:EXECute')



from typing import List

from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pattern:
	"""Pattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pattern", core, parent)

	def set(self, pattern: List[str], subframeNull=repcap.SubframeNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:XPDCch:DCRegs:PATTern \n
		Snippet: driver.source.bb.v5G.downlink.subf.encc.xpdcch.dcRegs.pattern.set(pattern = ['raw1', 'raw2', 'raw3'], subframeNull = repcap.SubframeNull.Default) \n
		Sets the bit pattern. The setting is relevant for [:SOURce<hw>]:BB:V5G:DL[:SUBF<st0>]:ENCC:XPDCch:DCRegs:DATAPATTern \n
			:param pattern: 64 bit
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')"""
		param = Conversions.list_to_csv_str(pattern)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:XPDCch:DCRegs:PATTern {param}')

	def get(self, subframeNull=repcap.SubframeNull.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:[SUBF<ST0>]:ENCC:XPDCch:DCRegs:PATTern \n
		Snippet: value: List[str] = driver.source.bb.v5G.downlink.subf.encc.xpdcch.dcRegs.pattern.get(subframeNull = repcap.SubframeNull.Default) \n
		Sets the bit pattern. The setting is relevant for [:SOURce<hw>]:BB:V5G:DL[:SUBF<st0>]:ENCC:XPDCch:DCRegs:DATAPATTern \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:return: pattern: 64 bit"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:SUBF{subframeNull_cmd_val}:ENCC:XPDCch:DCRegs:PATTern?')
		return Conversions.str_to_str_list(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Synchronization:
	"""Synchronization commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("synchronization", core, parent)

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import Execute
			self._execute = Execute(self._core, self._base)
		return self._execute

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ClocSyncMode:
		"""SCPI: [SOURce<HW>]:BB:NFC:CLOCk:SYNChronization:MODE \n
		Snippet: value: enums.ClocSyncMode = driver.source.bb.nfc.clock.synchronization.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NFC:CLOCk:SYNChronization:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ClocSyncMode)

	def set_mode(self, mode: enums.ClocSyncMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CLOCk:SYNChronization:MODE \n
		Snippet: driver.source.bb.nfc.clock.synchronization.set_mode(mode = enums.ClocSyncMode.NONE) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ClocSyncMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CLOCk:SYNChronization:MODE {param}')

	def clone(self) -> 'Synchronization':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Synchronization(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Catalog:
	"""Catalog commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("catalog", core, parent)

	def get(self, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:ULISt:CATalog \n
		Snippet: value: List[str] = driver.source.bb.gsm.frame.slot.subChannel.user.ulist.catalog.get(frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		This command reads out the files with user defined slot settings in the default directory. The default directory is set
		using command method RsSmw.MassMemory.currentDirectory. Only files with the file extension *.gsm_slu and *.gsm_hslu are
		listed. \n
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: catalog: string"""
		frameIx_cmd_val = self._base.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._base.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._base.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:ULISt:CATalog?')
		return Conversions.str_to_str_list(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Output:
	"""Output commands group definition. 5 total commands, 5 Sub-groups, 0 group commands
	Repeated Capability: Output, default value after init: Output.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("output", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_output_get', 'repcap_output_set', repcap.Output.Nr1)

	def repcap_output_set(self, enum_value: repcap.Output) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Output.Default
		Default value after init: Output.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_output_get(self) -> repcap.Output:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def delay(self):
		"""delay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_delay'):
			from .Delay import Delay
			self._delay = Delay(self._core, self._base)
		return self._delay

	@property
	def duration(self):
		"""duration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_duration'):
			from .Duration import Duration
			self._duration = Duration(self._core, self._base)
		return self._duration

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import Mode
			self._mode = Mode(self._core, self._base)
		return self._mode

	@property
	def post(self):
		"""post commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_post'):
			from .Post import Post
			self._post = Post(self._core, self._base)
		return self._post

	@property
	def pre(self):
		"""pre commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pre'):
			from .Pre import Pre
			self._pre = Pre(self._core, self._base)
		return self._pre

	def clone(self) -> 'Output':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Output(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LcMask:
	"""LcMask commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("lcMask", core, parent)

	def set(self, lc_mask: List[str], baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:LCMask \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.lcMask.set(lc_mask = ['raw1', 'raw2', 'raw3'], baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command sets the mask of the Long Code Generator of the base station. For the traffic channels, this value is
		specific for the selected radio configuration. The LC Mask is the same for all sub channels of a traffic channel. If the
		mask is modified for one of the sub channels, the new value is then automatically used by all other subchannels of this
		traffic channel. \n
			:param lc_mask: integer Range: #H0 to #H3FF FFFF FFFF
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')"""
		param = Conversions.list_to_csv_str(lc_mask)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:LCMask {param}')

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:LCMask \n
		Snippet: value: List[str] = driver.source.bb.c2K.bstation.cgroup.coffset.lcMask.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command sets the mask of the Long Code Generator of the base station. For the traffic channels, this value is
		specific for the selected radio configuration. The LC Mask is the same for all sub channels of a traffic channel. If the
		mask is modified for one of the sub channels, the new value is then automatically used by all other subchannels of this
		traffic channel. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: lc_mask: integer Range: #H0 to #H3FF FFFF FFFF"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:LCMask?')
		return Conversions.str_to_str_list(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, signal_state: bool, index=repcap.Index.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:SBAS:SIGNal:L5Band:EL5S<US>:[STATe] \n
		Snippet: driver.source.bb.gnss.system.sbas.signal.l5Band.el5S.state.set(signal_state = False, index = repcap.Index.Default) \n
		Enables the corresponding signal from the GNSS system in the corresponding RF band. \n
			:param signal_state: 0| 1| OFF| ON
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'El5S')"""
		param = Conversions.bool_to_str(signal_state)
		index_cmd_val = self._base.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SYSTem:SBAS:SIGNal:L5Band:EL5S{index_cmd_val}:STATe {param}')

	def get(self, index=repcap.Index.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:SBAS:SIGNal:L5Band:EL5S<US>:[STATe] \n
		Snippet: value: bool = driver.source.bb.gnss.system.sbas.signal.l5Band.el5S.state.get(index = repcap.Index.Default) \n
		Enables the corresponding signal from the GNSS system in the corresponding RF band. \n
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'El5S')
			:return: signal_state: 0| 1| OFF| ON"""
		index_cmd_val = self._base.get_repcap_cmd_value(index, repcap.Index)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SYSTem:SBAS:SIGNal:L5Band:EL5S{index_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Absolute:
	"""Absolute commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("absolute", core, parent)

	def get_set(self) -> str:
		"""SCPI: SYSTem:TIME:HRTimer:ABSolute:SET \n
		Snippet: value: str = driver.system.time.hrTimer.absolute.get_set() \n
		No command help available \n
			:return: pseudo_string: No help available
		"""
		response = self._core.io.query_str('SYSTem:TIME:HRTimer:ABSolute:SET?')
		return trim_str_response(response)

	def set_set(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TIME:HRTimer:ABSolute:SET \n
		Snippet: driver.system.time.hrTimer.absolute.set_set(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TIME:HRTimer:ABSolute:SET {param}')

	def set_value(self, pseudo_string: str) -> None:
		"""SCPI: SYSTem:TIME:HRTimer:ABSolute \n
		Snippet: driver.system.time.hrTimer.absolute.set_value(pseudo_string = '1') \n
		No command help available \n
			:param pseudo_string: No help available
		"""
		param = Conversions.value_to_quoted_str(pseudo_string)
		self._core.io.write(f'SYSTem:TIME:HRTimer:ABSolute {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ccoding:
	"""Ccoding commands group definition. 3 total commands, 1 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ccoding", core, parent)

	@property
	def interleaver(self):
		"""interleaver commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_interleaver'):
			from .Interleaver import Interleaver
			self._interleaver = Interleaver(self._core, self._base)
		return self._interleaver

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:PCCPch:CCODing:STATe \n
		Snippet: value: bool = driver.source.bb.w3Gpp.bstation.enhanced.pccpch.ccoding.get_state() \n
		The command activates or deactivates channel coding for the enhanced P-CCPCH. The coding scheme of the P-CCPCH (BCH) is
		defined in the standard. \n
			:return: state: ON| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:PCCPch:CCODing:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:PCCPch:CCODing:STATe \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.pccpch.ccoding.set_state(state = False) \n
		The command activates or deactivates channel coding for the enhanced P-CCPCH. The coding scheme of the P-CCPCH (BCH) is
		defined in the standard. \n
			:param state: ON| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:PCCPch:CCODing:STATe {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.CodeType:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:PCCPch:CCODing:TYPE \n
		Snippet: value: enums.CodeType = driver.source.bb.w3Gpp.bstation.enhanced.pccpch.ccoding.get_type_py() \n
		The command queries the channel coding scheme in accordance with the 3GPP specification. The coding scheme of the P-CCPCH
		(BCH) is defined in the standard. The channel is generated automatically with the counting system frame number (SFN) .
		The system information after the SFN field is completed from the selected data source. \n
			:return: type_py: BCHSfn
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:PCCPch:CCODing:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.CodeType)

	def clone(self) -> 'Ccoding':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ccoding(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Unscaled:
	"""Unscaled commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("unscaled", core, parent)

	def set(self, omega: float, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GPS:NMESsage:CNAV:EPHemeris:OMEGa:UNSCaled \n
		Snippet: driver.source.bb.gnss.svid.gps.nmessage.cnav.ephemeris.omega.unscaled.set(omega = 1.0, satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets the argument of perigee. \n
			:param omega: integer
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')"""
		param = Conversions.decimal_value_to_str(omega)
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GPS:NMESsage:CNAV:EPHemeris:OMEGa:UNSCaled {param}')

	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GPS:NMESsage:CNAV:EPHemeris:OMEGa:UNSCaled \n
		Snippet: value: float = driver.source.bb.gnss.svid.gps.nmessage.cnav.ephemeris.omega.unscaled.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets the argument of perigee. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: omega: integer"""
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GPS:NMESsage:CNAV:EPHemeris:OMEGa:UNSCaled?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class System:
	"""System commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("system", core, parent)

	def set(self, system: enums.Hybrid, monitorPane=repcap.MonitorPane.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay:TRAJectory:SYSTem \n
		Snippet: driver.source.bb.gnss.monitor.display.trajectory.system.set(system = enums.Hybrid.BEIDou, monitorPane = repcap.MonitorPane.Default) \n
		Selects the GNSS system which elevation/azimuth variation over 24 hours is displayed. \n
			:param system: GPS| GALileo| GLONass| BEIDou| QZSS| SBAS
			:param monitorPane: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')"""
		param = Conversions.enum_scalar_to_str(system, enums.Hybrid)
		monitorPane_cmd_val = self._base.get_repcap_cmd_value(monitorPane, repcap.MonitorPane)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:MONitor{monitorPane_cmd_val}:DISPlay:TRAJectory:SYSTem {param}')

	# noinspection PyTypeChecker
	def get(self, monitorPane=repcap.MonitorPane.Default) -> enums.Hybrid:
		"""SCPI: [SOURce<HW>]:BB:GNSS:MONitor<CH>:DISPlay:TRAJectory:SYSTem \n
		Snippet: value: enums.Hybrid = driver.source.bb.gnss.monitor.display.trajectory.system.get(monitorPane = repcap.MonitorPane.Default) \n
		Selects the GNSS system which elevation/azimuth variation over 24 hours is displayed. \n
			:param monitorPane: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Monitor')
			:return: system: GPS| GALileo| GLONass| BEIDou| QZSS| SBAS"""
		monitorPane_cmd_val = self._base.get_repcap_cmd_value(monitorPane, repcap.MonitorPane)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:MONitor{monitorPane_cmd_val}:DISPlay:TRAJectory:SYSTem?')
		return Conversions.str_to_scalar_enum(response, enums.Hybrid)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Quadrature:
	"""Quadrature commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("quadrature", core, parent)

	def get_angle(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:QUADrature:[ANGLe] \n
		Snippet: value: float = driver.source.iq.impairment.quadrature.get_angle() \n
		Sets a quadrature offset (phase angle) between the I and Q vectors deviating from the ideal 90 degrees.
		A positive quadrature offset results in a phase angle greater than 90 degrees. Value range
			Table Header: Impairments / Min [dB] / Max [dB] / Resolution \n
			- Digital / 30 / 30 / 0.01
			- Analog / 10 / 10 / 0.01 \n
			:return: angle: float Range: -30 to 30, Unit: DEG
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:IMPairment:QUADrature:ANGLe?')
		return Conversions.str_to_float(response)

	def set_angle(self, angle: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:QUADrature:[ANGLe] \n
		Snippet: driver.source.iq.impairment.quadrature.set_angle(angle = 1.0) \n
		Sets a quadrature offset (phase angle) between the I and Q vectors deviating from the ideal 90 degrees.
		A positive quadrature offset results in a phase angle greater than 90 degrees. Value range
			Table Header: Impairments / Min [dB] / Max [dB] / Resolution \n
			- Digital / 30 / 30 / 0.01
			- Analog / 10 / 10 / 0.01 \n
			:param angle: float Range: -30 to 30, Unit: DEG
		"""
		param = Conversions.decimal_value_to_str(angle)
		self._core.io.write(f'SOURce<HwInstance>:IQ:IMPairment:QUADrature:ANGLe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Output:
	"""Output commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("output", core, parent)

	def get_frequency(self) -> float:
		"""SCPI: [SOURce<HW>]:FREQuency:LOSCillator:OUTPut:FREQuency \n
		Snippet: value: float = driver.source.frequency.loscillator.output.get_frequency() \n
		Queries the current frequency of the local oscillator at the [LO OUT] connector. \n
			:return: frequency: float Range: 100E3 to 20E9
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FREQuency:LOSCillator:OUTPut:FREQuency?')
		return Conversions.str_to_float(response)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:FREQuency:LOSCillator:OUTPut:STATe \n
		Snippet: value: bool = driver.source.frequency.loscillator.output.get_state() \n
		Activates the LO output in the second path. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FREQuency:LOSCillator:OUTPut:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:FREQuency:LOSCillator:OUTPut:STATe \n
		Snippet: driver.source.frequency.loscillator.output.set_state(state = False) \n
		Activates the LO output in the second path. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:FREQuency:LOSCillator:OUTPut:STATe {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rise:
	"""Rise commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rise", core, parent)

	def set(self, rise: float, lfOutput=repcap.LfOutput.Default) -> None:
		"""SCPI: [SOURce<HW>]:LFOutput<CH>:SHAPe:TRIangle:RISE \n
		Snippet: driver.source.lfOutput.shape.triangle.rise.set(rise = 1.0, lfOutput = repcap.LfOutput.Default) \n
		Selects the rise time for the triangle single of the LF generator. \n
			:param rise: float Range: 1E-6 to 100
			:param lfOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'LfOutput')"""
		param = Conversions.decimal_value_to_str(rise)
		lfOutput_cmd_val = self._base.get_repcap_cmd_value(lfOutput, repcap.LfOutput)
		self._core.io.write(f'SOURce<HwInstance>:LFOutput{lfOutput_cmd_val}:SHAPe:TRIangle:RISE {param}')

	def get(self, lfOutput=repcap.LfOutput.Default) -> float:
		"""SCPI: [SOURce<HW>]:LFOutput<CH>:SHAPe:TRIangle:RISE \n
		Snippet: value: float = driver.source.lfOutput.shape.triangle.rise.get(lfOutput = repcap.LfOutput.Default) \n
		Selects the rise time for the triangle single of the LF generator. \n
			:param lfOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'LfOutput')
			:return: rise: float Range: 1E-6 to 100"""
		lfOutput_cmd_val = self._base.get_repcap_cmd_value(lfOutput, repcap.LfOutput)
		response = self._core.io.query_str(f'SOURce<HwInstance>:LFOutput{lfOutput_cmd_val}:SHAPe:TRIangle:RISE?')
		return Conversions.str_to_float(response)



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZpDelta:
	"""ZpDelta commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zpDelta", core, parent)

	def get(self, cellNull=repcap.CellNull.Default, indexNull=repcap.IndexNull.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CSIS:[CELL<CH0>]:[ZPRS<ST0>]:ZPDelta \n
		Snippet: value: List[str] = driver.source.bb.eutra.downlink.csis.cell.zprs.zpDelta.get(cellNull = repcap.CellNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the parameter subframe offset ΔCSI-RS for CSI-RS with zero transmission power. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Zprs')
			:return: zero_power_offset: integer"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		indexNull_cmd_val = self._base.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:CSIS:CELL{cellNull_cmd_val}:ZPRS{indexNull_cmd_val}:ZPDelta?')
		return Conversions.str_to_str_list(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reference:
	"""Reference commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("reference", core, parent)

	def set(self, profile_ref_time: float, satelliteSvid=repcap.SatelliteSvid.Default, index=repcap.Index.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:BEIDou:PRERrors:PROFile<GR>:REFerence \n
		Snippet: driver.source.bb.gnss.svid.beidou.prErrors.profile.reference.set(profile_ref_time = 1.0, satelliteSvid = repcap.SatelliteSvid.Default, index = repcap.Index.Default) \n
		Sets the reference time for the pseudorange error. \n
			:param profile_ref_time: float Range: 0 to 86400
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Profile')"""
		param = Conversions.decimal_value_to_str(profile_ref_time)
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		index_cmd_val = self._base.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:BEIDou:PRERrors:PROFile{index_cmd_val}:REFerence {param}')

	def get(self, satelliteSvid=repcap.SatelliteSvid.Default, index=repcap.Index.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:BEIDou:PRERrors:PROFile<GR>:REFerence \n
		Snippet: value: float = driver.source.bb.gnss.svid.beidou.prErrors.profile.reference.get(satelliteSvid = repcap.SatelliteSvid.Default, index = repcap.Index.Default) \n
		Sets the reference time for the pseudorange error. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Profile')
			:return: profile_ref_time: float Range: 0 to 86400"""
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		index_cmd_val = self._base.get_repcap_cmd_value(index, repcap.Index)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:BEIDou:PRERrors:PROFile{index_cmd_val}:REFerence?')
		return Conversions.str_to_float(response)



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Catalog:
	"""Catalog commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("catalog", core, parent)

	def set(self, gnss_location_names: List[str], baseSt=repcap.BaseSt.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:BASE<ST>:LOCation:CATalog \n
		Snippet: driver.source.bb.gnss.rtk.base.location.catalog.set(gnss_location_names = ['1', '2', '3'], baseSt = repcap.BaseSt.Default) \n
		No command help available \n
			:param gnss_location_names: No help available
			:param baseSt: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Base')"""
		param = Conversions.list_to_csv_quoted_str(gnss_location_names)
		baseSt_cmd_val = self._base.get_repcap_cmd_value(baseSt, repcap.BaseSt)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RTK:BASE{baseSt_cmd_val}:LOCation:CATalog {param}')

	def get(self, baseSt=repcap.BaseSt.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:BASE<ST>:LOCation:CATalog \n
		Snippet: value: List[str] = driver.source.bb.gnss.rtk.base.location.catalog.get(baseSt = repcap.BaseSt.Default) \n
		No command help available \n
			:param baseSt: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Base')
			:return: gnss_location_names: No help available"""
		baseSt_cmd_val = self._base.get_repcap_cmd_value(baseSt, repcap.BaseSt)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RTK:BASE{baseSt_cmd_val}:LOCation:CATalog?')
		return Conversions.str_to_str_list(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sps:
	"""Sps commands group definition. 5 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sps", core, parent)

	@property
	def crnti(self):
		"""crnti commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_crnti'):
			from .Crnti import Crnti
			self._crnti = Crnti(self._core, self._base)
		return self._crnti

	@property
	def sactivation(self):
		"""sactivation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sactivation'):
			from .Sactivation import Sactivation
			self._sactivation = Sactivation(self._core, self._base)
		return self._sactivation

	@property
	def sinterval(self):
		"""sinterval commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sinterval'):
			from .Sinterval import Sinterval
			self._sinterval = Sinterval(self._core, self._base)
		return self._sinterval

	@property
	def srelease(self):
		"""srelease commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srelease'):
			from .Srelease import Srelease
			self._srelease = Srelease(self._core, self._base)
		return self._srelease

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	def clone(self) -> 'Sps':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sps(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Path:
	"""Path commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("path", core, parent)

	def get_count(self) -> int:
		"""SCPI: [SOURce]:BB:PATH:COUNt \n
		Snippet: value: int = driver.source.bb.path.get_count() \n
		No command help available \n
			:return: count: No help available
		"""
		response = self._core.io.query_str('SOURce:BB:PATH:COUNt?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IqRatio:
	"""IqRatio commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("iqRatio", core, parent)

	def get_magnitude(self) -> float:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:IQRatio:[MAGNitude] \n
		Snippet: value: float = driver.source.iq.impairment.iqRatio.get_magnitude() \n
		Sets the ratio of I modulation to Q modulation (amplification imbalance) of the corresponding digital channel.
		Value range
			Table Header: Impairments / Min [dB] / Max [dB] / Resolution \n
			- Digital / 4 / 4 / 0.0001
			- Analog / 1 / 1 / 0.0001 \n
			:return: magnitude: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:IQ:IMPairment:IQRatio:MAGNitude?')
		return Conversions.str_to_float(response)

	def set_magnitude(self, magnitude: float) -> None:
		"""SCPI: [SOURce<HW>]:IQ:IMPairment:IQRatio:[MAGNitude] \n
		Snippet: driver.source.iq.impairment.iqRatio.set_magnitude(magnitude = 1.0) \n
		Sets the ratio of I modulation to Q modulation (amplification imbalance) of the corresponding digital channel.
		Value range
			Table Header: Impairments / Min [dB] / Max [dB] / Resolution \n
			- Digital / 4 / 4 / 0.0001
			- Analog / 1 / 1 / 0.0001 \n
			:param magnitude: float The setting value can be either in dB or %. An input in percent is rounded to the closest valid value in dB. Range: -4 to 4, Unit: dB | PCT (setting command) / dB (result value)
		"""
		param = Conversions.decimal_value_to_str(magnitude)
		self._core.io.write(f'SOURce<HwInstance>:IQ:IMPairment:IQRatio:MAGNitude {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Msas:
	"""Msas commands group definition. 24 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("msas", core, parent)

	@property
	def nmessage(self):
		"""nmessage commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_nmessage'):
			from .Nmessage import Nmessage
			self._nmessage = Nmessage(self._core, self._base)
		return self._nmessage

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:SBAS:MSAS:[STATe] \n
		Snippet: value: bool = driver.source.bb.gnss.system.sbas.msas.get_state() \n
		Defines if satellites from the selected GNSS system are included in the simulated satellites constellation. \n
			:return: state: 0| 1| OFF| ON Disabling a GNSS system deactivates all SVID and signals from this system.
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SYSTem:SBAS:MSAS:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SYSTem:SBAS:MSAS:[STATe] \n
		Snippet: driver.source.bb.gnss.system.sbas.msas.set_state(state = False) \n
		Defines if satellites from the selected GNSS system are included in the simulated satellites constellation. \n
			:param state: 0| 1| OFF| ON Disabling a GNSS system deactivates all SVID and signals from this system.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SYSTem:SBAS:MSAS:STATe {param}')

	def clone(self) -> 'Msas':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Msas(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Connector:
	"""Connector commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("connector", core, parent)

	def set(self, connector: enums.FeedbackConnector, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DPControl:CONNector \n
		Snippet: driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.connector.set(connector = enums.FeedbackConnector.GLOBal, channelNull = repcap.ChannelNull.Default) \n
		Determines the input connector at that the instrument expects the external control signal. \n
			:param connector: LOCal| GLOBal
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.enum_scalar_to_str(connector, enums.FeedbackConnector)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:CONNector {param}')

	# noinspection PyTypeChecker
	def get(self, channelNull=repcap.ChannelNull.Default) -> enums.FeedbackConnector:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation:ENHanced:CHANnel<CH0>:DPCH:DPControl:CONNector \n
		Snippet: value: enums.FeedbackConnector = driver.source.bb.w3Gpp.bstation.enhanced.channel.dpch.dpControl.connector.get(channelNull = repcap.ChannelNull.Default) \n
		Determines the input connector at that the instrument expects the external control signal. \n
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: connector: LOCal| GLOBal"""
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation:ENHanced:CHANnel{channelNull_cmd_val}:DPCH:DPControl:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.FeedbackConnector)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Umotion:
	"""Umotion commands group definition. 24 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("umotion", core, parent)

	@property
	def csv(self):
		"""csv commands group. 6 Sub-classes, 8 commands."""
		if not hasattr(self, '_csv'):
			from .Csv import Csv
			self._csv = Csv(self._core, self._base)
		return self._csv

	# noinspection PyTypeChecker
	def get_format_py(self) -> enums.LogFmtSat:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:FORMat \n
		Snippet: value: enums.LogFmtSat = driver.source.bb.gnss.logging.category.umotion.get_format_py() \n
		Sets the file format in that the logged data is saved. \n
			:return: format_py: CSV
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.LogFmtSat)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:STATe \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.umotion.get_state() \n
		Enables the logging of the selected category. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:STATe \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.set_state(state = False) \n
		Enables the logging of the selected category. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:STATe {param}')

	# noinspection PyTypeChecker
	def get_step(self) -> enums.LogRes:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:STEP \n
		Snippet: value: enums.LogRes = driver.source.bb.gnss.logging.category.umotion.get_step() \n
		Sets the logging step. \n
			:return: resolution: R1S| R2S| R5S| R10S| R02S| R04S| R08S
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:STEP?')
		return Conversions.str_to_scalar_enum(response, enums.LogRes)

	def set_step(self, resolution: enums.LogRes) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:UMOTion:STEP \n
		Snippet: driver.source.bb.gnss.logging.category.umotion.set_step(resolution = enums.LogRes.R02S) \n
		Sets the logging step. \n
			:param resolution: R1S| R2S| R5S| R10S| R02S| R04S| R08S
		"""
		param = Conversions.enum_scalar_to_str(resolution, enums.LogRes)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:UMOTion:STEP {param}')

	def clone(self) -> 'Umotion':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Umotion(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Satellite:
	"""Satellite commands group definition. 22 total commands, 4 Sub-groups, 17 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("satellite", core, parent)

	@property
	def acceleration(self):
		"""acceleration commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_acceleration'):
			from .Acceleration import Acceleration
			self._acceleration = Acceleration(self._core, self._base)
		return self._acceleration

	@property
	def position(self):
		"""position commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_position'):
			from .Position import Position
			self._position = Position(self._core, self._base)
		return self._position

	@property
	def select(self):
		"""select commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_select'):
			from .Select import Select
			self._select = Select(self._core, self._base)
		return self._select

	@property
	def velocity(self):
		"""velocity commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_velocity'):
			from .Velocity import Velocity
			self._velocity = Velocity(self._core, self._base)
		return self._velocity

	def get_azimuth(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:AZIMuth \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_azimuth() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:AZIMuth?')
		return Conversions.str_to_bool(response)

	def set_azimuth(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:AZIMuth \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_azimuth(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:AZIMuth {param}')

	def get_cbias(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:CBIas \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_cbias() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:CBIas?')
		return Conversions.str_to_bool(response)

	def set_cbias(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:CBIas \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_cbias(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:CBIas {param}')

	def get_cphase(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:CPHase \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_cphase() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:CPHase?')
		return Conversions.str_to_bool(response)

	def set_cphase(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:CPHase \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_cphase(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:CPHase {param}')

	def get_dshift(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:DSHift \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_dshift() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:DSHift?')
		return Conversions.str_to_bool(response)

	def set_dshift(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:DSHift \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_dshift(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:DSHift {param}')

	def get_elevation(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:ELEVation \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_elevation() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:ELEVation?')
		return Conversions.str_to_bool(response)

	def set_elevation(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:ELEVation \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_elevation(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:ELEVation {param}')

	# noinspection PyTypeChecker
	def get_format_py(self) -> enums.LogFmtSat:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:FORMat \n
		Snippet: value: enums.LogFmtSat = driver.source.bb.gnss.logging.category.satellite.get_format_py() \n
		Sets the file format in that the logged data is saved. \n
			:return: format_py: CSV
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.LogFmtSat)

	def get_idelay(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:IDELay \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_idelay() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:IDELay?')
		return Conversions.str_to_bool(response)

	def set_idelay(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:IDELay \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_idelay(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:IDELay {param}')

	def get_prange(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRANge \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_prange() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRANge?')
		return Conversions.str_to_bool(response)

	def set_prange(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRANge \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_prange(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRANge {param}')

	def get_prb_rate(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRBRate \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_prb_rate() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRBRate?')
		return Conversions.str_to_bool(response)

	def set_prb_rate(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRBRate \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_prb_rate(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRBRate {param}')

	def get_pr_bias(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRBias \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_pr_bias() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRBias?')
		return Conversions.str_to_bool(response)

	def set_pr_bias(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRBias \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_pr_bias(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRBias {param}')

	def get_pr_rate(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRRate \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_pr_rate() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRRate?')
		return Conversions.str_to_bool(response)

	def set_pr_rate(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:PRRate \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_pr_rate(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:PRRate {param}')

	def get_range(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:RANGe \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_range() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:RANGe?')
		return Conversions.str_to_bool(response)

	def set_range(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:RANGe \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_range(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:RANGe {param}')

	def get_rrate(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:RRATe \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_rrate() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:RRATe?')
		return Conversions.str_to_bool(response)

	def set_rrate(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:RRATe \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_rrate(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:RRATe {param}')

	def get_slevel(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:SLEVel \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_slevel() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:SLEVel?')
		return Conversions.str_to_bool(response)

	def set_slevel(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:SLEVel \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_slevel(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:SLEVel {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:STATe \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_state() \n
		Enables the logging of the selected category. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:STATe \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_state(state = False) \n
		Enables the logging of the selected category. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:STATe {param}')

	# noinspection PyTypeChecker
	def get_step(self) -> enums.LogRes:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:STEP \n
		Snippet: value: enums.LogRes = driver.source.bb.gnss.logging.category.satellite.get_step() \n
		Sets the logging step. \n
			:return: resolution: R1S| R2S| R5S| R10S| R02S| R04S| R08S
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:STEP?')
		return Conversions.str_to_scalar_enum(response, enums.LogRes)

	def set_step(self, resolution: enums.LogRes) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:STEP \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_step(resolution = enums.LogRes.R02S) \n
		Sets the logging step. \n
			:param resolution: R1S| R2S| R5S| R10S| R02S| R04S| R08S
		"""
		param = Conversions.enum_scalar_to_str(resolution, enums.LogRes)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:STEP {param}')

	def get_tdelay(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:TDELay \n
		Snippet: value: bool = driver.source.bb.gnss.logging.category.satellite.get_tdelay() \n
		Enables the parameter for logging. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:TDELay?')
		return Conversions.str_to_bool(response)

	def set_tdelay(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:LOGGing:CATegory:SATellite:TDELay \n
		Snippet: driver.source.bb.gnss.logging.category.satellite.set_tdelay(state = False) \n
		Enables the parameter for logging. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:LOGGing:CATegory:SATellite:TDELay {param}')

	def clone(self) -> 'Satellite':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Satellite(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dpch:
	"""Dpch commands group definition. 37 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dpch", core, parent)

	@property
	def ccoding(self):
		"""ccoding commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_ccoding'):
			from .Ccoding import Ccoding
			self._ccoding = Ccoding(self._core, self._base)
		return self._ccoding

	@property
	def derror(self):
		"""derror commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_derror'):
			from .Derror import Derror
			self._derror = Derror(self._core, self._base)
		return self._derror

	@property
	def dpControl(self):
		"""dpControl commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_dpControl'):
			from .DpControl import DpControl
			self._dpControl = DpControl(self._core, self._base)
		return self._dpControl

	@property
	def interleaver2(self):
		"""interleaver2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_interleaver2'):
			from .Interleaver2 import Interleaver2
			self._interleaver2 = Interleaver2(self._core, self._base)
		return self._interleaver2

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def tchannel(self):
		"""tchannel commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_tchannel'):
			from .Tchannel import Tchannel
			self._tchannel = Tchannel(self._core, self._base)
		return self._tchannel

	def clone(self) -> 'Dpch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dpch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RbCount:
	"""RbCount commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rbCount", core, parent)

	def set(self, number_of_rbs: int, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default, setItem=repcap.SetItem.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:[CELL<CCIDX>]:[SUBF<ST0>]:ALLoc<CH0>:PUSCh:SET<USER>:RBCount \n
		Snippet: driver.source.bb.oneweb.uplink.cell.subf.alloc.pusch.set.rbCount.set(number_of_rbs = 1, cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default, setItem = repcap.SetItem.Default) \n
		Sets the size of the selected allocation in resource blocks (per subframe) . \n
			:param number_of_rbs: integer Range: 0 to 110
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param setItem: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Set')"""
		param = Conversions.decimal_value_to_str(number_of_rbs)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		setItem_cmd_val = self._base.get_repcap_cmd_value(setItem, repcap.SetItem)
		self._core.io.write(f'SOURce<HwInstance>:BB:ONEWeb:UL:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:SET{setItem_cmd_val}:RBCount {param}')

	def get(self, cellNull=repcap.CellNull.Default, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default, setItem=repcap.SetItem.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:UL:[CELL<CCIDX>]:[SUBF<ST0>]:ALLoc<CH0>:PUSCh:SET<USER>:RBCount \n
		Snippet: value: int = driver.source.bb.oneweb.uplink.cell.subf.alloc.pusch.set.rbCount.get(cellNull = repcap.CellNull.Default, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default, setItem = repcap.SetItem.Default) \n
		Sets the size of the selected allocation in resource blocks (per subframe) . \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param setItem: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Set')
			:return: number_of_rbs: integer Range: 0 to 110"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		setItem_cmd_val = self._base.get_repcap_cmd_value(setItem, repcap.SetItem)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:UL:CELL{cellNull_cmd_val}:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:PUSCh:SET{setItem_cmd_val}:RBCount?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Connection:
	"""Connection commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("connection", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:EFRontend:CONNection:STATe \n
		Snippet: value: bool = driver.source.efrontend.connection.get_state() \n
		Queries the state of the connection between R&S SMW and external frontend. \n
			:return: conn_state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:EFRontend:CONNection:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, conn_state: bool) -> None:
		"""SCPI: [SOURce<HW>]:EFRontend:CONNection:STATe \n
		Snippet: driver.source.efrontend.connection.set_state(conn_state = False) \n
		Queries the state of the connection between R&S SMW and external frontend. \n
			:param conn_state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(conn_state)
		self._core.io.write(f'SOURce<HwInstance>:EFRontend:CONNection:STATe {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Types import DataType
from ........Internal.ArgSingleList import ArgSingleList
from ........Internal.ArgSingle import ArgSingle
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rvelocity:
	"""Rvelocity commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rvelocity", core, parent)

	def get(self, time_basis: enums.TimeBasis, year: int, month: int, day: int, hour: int, minutes: int, seconds: float, week_number: int, time_of_week: float, vehicle=repcap.Vehicle.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RT:RECeiver:[V<ST>]:RVELocity \n
		Snippet: value: float = driver.source.bb.gnss.rt.receiver.v.rvelocity.get(time_basis = enums.TimeBasis.BDT, year = 1, month = 1, day = 1, hour = 1, minutes = 1, seconds = 1.0, week_number = 1, time_of_week = 1.0, vehicle = repcap.Vehicle.Default) \n
		Queries the velocity of the receiver location for the selected moment of time. The required query parameters depend on
		the selected timebase. \n
			:param time_basis: select
			:param year: integer Range: 1980 to 9999
			:param month: integer Range: 1 to 12
			:param day: integer Range: 1 to 31
			:param hour: integer Range: 0 to 23
			:param minutes: integer Range: 0 to 59
			:param seconds: float Range: 0 to 59.999
			:param week_number: integer Range: 0 to 529947
			:param time_of_week: float Range: 0 to 604799.999
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: velocity: float Range: 0 to 1000"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('time_basis', time_basis, DataType.Enum), ArgSingle('year', year, DataType.Integer), ArgSingle('month', month, DataType.Integer), ArgSingle('day', day, DataType.Integer), ArgSingle('hour', hour, DataType.Integer), ArgSingle('minutes', minutes, DataType.Integer), ArgSingle('seconds', seconds, DataType.Float), ArgSingle('week_number', week_number, DataType.Integer), ArgSingle('time_of_week', time_of_week, DataType.Float))
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RT:RECeiver:V{vehicle_cmd_val}:RVELocity? {param}'.rstrip())
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Imaginary:
	"""Imaginary commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("imaginary", core, parent)

	def set(self, api_mag: float, cellNull=repcap.CellNull.Nr0, columnNull=repcap.ColumnNull.Default, rowNull=repcap.RowNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:DUMRes:APMap:COL<ST0>:ROW<DIR0>:IMAGinary \n
		Snippet: driver.source.bb.nr5G.node.cell.dumRes.apMap.col.row.imaginary.set(api_mag = 1.0, cellNull = repcap.CellNull.Nr0, columnNull = repcap.ColumnNull.Default, rowNull = repcap.RowNull.Default) \n
		Define the mapping of the antenna ports to the physical antennas for unused (dummy) resource elements in cartesian
		mapping format (imaginary value) . \n
			:param api_mag: float Range: -1 to 1
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param columnNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Col')
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')"""
		param = Conversions.decimal_value_to_str(api_mag)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		columnNull_cmd_val = self._base.get_repcap_cmd_value(columnNull, repcap.ColumnNull)
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:DUMRes:APMap:COL{columnNull_cmd_val}:ROW{rowNull_cmd_val}:IMAGinary {param}')

	def get(self, cellNull=repcap.CellNull.Nr0, columnNull=repcap.ColumnNull.Default, rowNull=repcap.RowNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:DUMRes:APMap:COL<ST0>:ROW<DIR0>:IMAGinary \n
		Snippet: value: float = driver.source.bb.nr5G.node.cell.dumRes.apMap.col.row.imaginary.get(cellNull = repcap.CellNull.Nr0, columnNull = repcap.ColumnNull.Default, rowNull = repcap.RowNull.Default) \n
		Define the mapping of the antenna ports to the physical antennas for unused (dummy) resource elements in cartesian
		mapping format (imaginary value) . \n
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param columnNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Col')
			:param rowNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Row')
			:return: api_mag: float Range: -1 to 1"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		columnNull_cmd_val = self._base.get_repcap_cmd_value(columnNull, repcap.ColumnNull)
		rowNull_cmd_val = self._base.get_repcap_cmd_value(rowNull, repcap.RowNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:DUMRes:APMap:COL{columnNull_cmd_val}:ROW{rowNull_cmd_val}:IMAGinary?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Zero:
	"""Zero commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("zero", core, parent)

	def set(self, channel=repcap.Channel.Default) -> None:
		"""SCPI: SENSe<CH>:[POWer]:ZERO \n
		Snippet: driver.sense.power.zero.set(channel = repcap.Channel.Default) \n
		Performs zeroing of the sensor. Zeroing is required after warm-up, i.e. after connecting the sensor. Note: Switch off or
		disconnect the RF power source from the sensor before zeroing.
			INTRO_CMD_HELP: We recommend that you zero in regular intervals (at least once a day) , if: \n
			- The temperature has varied more than about 5 °C.
			- The sensor has been replaced.
			- You want to measure very low power. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SENSe{channel_cmd_val}:POWer:ZERO')

	def set_with_opc(self, channel=repcap.Channel.Default) -> None:
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		"""SCPI: SENSe<CH>:[POWer]:ZERO \n
		Snippet: driver.sense.power.zero.set_with_opc(channel = repcap.Channel.Default) \n
		Performs zeroing of the sensor. Zeroing is required after warm-up, i.e. after connecting the sensor. Note: Switch off or
		disconnect the RF power source from the sensor before zeroing.
			INTRO_CMD_HELP: We recommend that you zero in regular intervals (at least once a day) , if: \n
			- The temperature has varied more than about 5 °C.
			- The sensor has been replaced.
			- You want to measure very low power. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')"""
		self._core.io.write_with_opc(f'SENSe{channel_cmd_val}:POWer:ZERO')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MuNum:
	"""MuNum commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: Station, default value after init: Station.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("muNum", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_station_get', 'repcap_station_set', repcap.Station.Nr1)

	def repcap_station_set(self, enum_value: repcap.Station) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Station.Default
		Default value after init: Station.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_station_get(self) -> repcap.Station:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, mu_num_ch_2: int, frameBlock=repcap.FrameBlock.Default, station=repcap.Station.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:CCH2:MUNum<ST> \n
		Snippet: driver.source.bb.wlnn.fblock.cch2.muNum.set(mu_num_ch_2 = 1, frameBlock = repcap.FrameBlock.Default, station = repcap.Station.Default) \n
		Sets the number of MU-MIMO users for each RU and station of the second content channel. \n
			:param mu_num_ch_2: integer Range: 0 to 8
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param station: optional repeated capability selector. Default value: Nr1 (settable in the interface 'MuNum')"""
		param = Conversions.decimal_value_to_str(mu_num_ch_2)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		station_cmd_val = self._base.get_repcap_cmd_value(station, repcap.Station)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:CCH2:MUNum{station_cmd_val} {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, station=repcap.Station.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:CCH2:MUNum<ST> \n
		Snippet: value: int = driver.source.bb.wlnn.fblock.cch2.muNum.get(frameBlock = repcap.FrameBlock.Default, station = repcap.Station.Default) \n
		Sets the number of MU-MIMO users for each RU and station of the second content channel. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param station: optional repeated capability selector. Default value: Nr1 (settable in the interface 'MuNum')
			:return: mu_num_ch_2: integer Range: 0 to 8"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		station_cmd_val = self._base.get_repcap_cmd_value(station, repcap.Station)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:CCH2:MUNum{station_cmd_val}?')
		return Conversions.str_to_int(response)

	def clone(self) -> 'MuNum':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MuNum(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ncces:
	"""Ncces commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ncces", core, parent)

	def get(self, subframeNull=repcap.SubframeNull.Default, itemNull=repcap.ItemNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:ONEWeb:DL:[SUBF<ST0>]:ENCC:PDCCh:EXTC:ITEM<CH0>:NCCes \n
		Snippet: value: int = driver.source.bb.oneweb.downlink.subf.encc.pdcch.extc.item.ncces.get(subframeNull = repcap.SubframeNull.Default, itemNull = repcap.ItemNull.Default) \n
		Queries the number of control channel elements used for the transmission of the PDCCH. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param itemNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Item')
			:return: cce_count: integer Range: 0 to 1E5"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		itemNull_cmd_val = self._base.get_repcap_cmd_value(itemNull, repcap.ItemNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:ONEWeb:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:EXTC:ITEM{itemNull_cmd_val}:NCCes?')
		return Conversions.str_to_int(response)
